@@ -1,7 +1,7 @@
 package Perinci::Sub::Wrapper;
 
-our $DATE = '2017-07-10'; # DATE
-our $VERSION = '0.84'; # VERSION
+our $DATE = '2019-04-15'; # DATE
+our $VERSION = '0.850'; # VERSION
 
 use 5.010001;
 use strict;
@@ -487,7 +487,7 @@ sub handle_args_as {
             my $pos = int($as->{pos} + 0);
             $pos >= 0 or die "Error in args property for arg '$a': ".
                 "negative value in pos";
-            if ($as->{greedy}) {
+            if ($as->{slurpy} // $as->{greedy}) {
                 if ($ref) {
                     $line .= '[splice @{$_[0]}, '.$pos.'] if @{$_[0]} > '.$pos;
                 } else {
@@ -536,7 +536,7 @@ sub handle_args_as {
             my $pos = int($as->{pos} + 0);
             $pos >= 0 or die "Error in args property for arg '$a': ".
                 "negative value in pos";
-            if ($as->{greedy}) {
+            if ($as->{slurpy} // $as->{greedy}) {
                 $line = 'splice @args, '.$pos.', scalar(@args)-1, @{'.$t.'}';
             } else {
                 $line = '$args'.($ref ? '->':'').'['.$pos."] = $t if exists $t";
@@ -1474,7 +1474,7 @@ Perinci::Sub::Wrapper - A multi-purpose subroutine wrapping framework
 
 =head1 VERSION
 
-This document describes version 0.84 of Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2017-07-10.
+This document describes version 0.850 of Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2019-04-15.
 
 =head1 SYNOPSIS
 
@@ -1631,7 +1631,7 @@ mil/sec.
 
 Usage:
 
- wrap_sub(%args) -> [status, msg, result, meta]
+ wrap_sub(%args) -> [status, msg, payload, meta]
 
 Wrap subroutine to do various things, like enforcing Rinci properties.
 
@@ -1730,7 +1730,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -1878,7 +1878,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
